==> atriumsports_sdk-1.0.0.tar.gz: atriumsports_sdk-1.0.0/atriumsports/datacore/openapi/api/__init__.py <==
from __future__ import absolute_import

# import apis into api package
from atriumsports.datacore.openapi.api.awards_api import AwardsApi
from atriumsports.datacore.openapi.api.career_statistics_api import CareerStatisticsApi
from atriumsports.datacore.openapi.api.change_log_api import ChangeLogApi
from atriumsports.datacore.openapi.api.competition_statistics_api import CompetitionStatisticsApi
from atriumsports.datacore.openapi.api.competitions_api import CompetitionsApi
from atriumsports.datacore.openapi.api.conduct_api import ConductApi
from atriumsports.datacore.openapi.api.conferences_divisions_api import ConferencesDivisionsApi
from atriumsports.datacore.openapi.api.download_video_api import DownloadVideoApi
from atriumsports.datacore.openapi.api.entities_api import EntitiesApi
from atriumsports.datacore.openapi.api.entity_fixture_history_api import EntityFixtureHistoryApi
from atriumsports.datacore.openapi.api.entity_fixture_statistics_api import EntityFixtureStatisticsApi
from atriumsports.datacore.openapi.api.entity_groups_api import EntityGroupsApi
from atriumsports.datacore.openapi.api.fixture_entities_api import FixtureEntitiesApi
from atriumsports.datacore.openapi.api.fixture_live_summary_api import FixtureLiveSummaryApi
from atriumsports.datacore.openapi.api.fixture_persons_api import FixturePersonsApi
from atriumsports.datacore.openapi.api.fixture_playbyplay_api import FixturePLAYBYPLAYApi
from atriumsports.datacore.openapi.api.fixture_profiles_api import FixtureProfilesApi
from atriumsports.datacore.openapi.api.fixture_progressions_api import FixtureProgressionsApi
from atriumsports.datacore.openapi.api.fixture_roster_api import FixtureRosterApi
from atriumsports.datacore.openapi.api.fixtures_api import FixturesApi
from atriumsports.datacore.openapi.api.images_api import ImagesApi
from atriumsports.datacore.openapi.api.leader_criteria_sets_api import LeaderCriteriaSetsApi
from atriumsports.datacore.openapi.api.leader_qualifiers_api import LeaderQualifiersApi
from atriumsports.datacore.openapi.api.leagues_api import LeaguesApi
from atriumsports.datacore.openapi.api.local_video_endpoints_api import LocalVideoEndpointsApi
from atriumsports.datacore.openapi.api.merge_records_api import MergeRecordsApi
from atriumsports.datacore.openapi.api.organizations_api import OrganizationsApi
from atriumsports.datacore.openapi.api.partner_apis_api import PartnerAPIsApi
from atriumsports.datacore.openapi.api.person_fixture_history_api import PersonFixtureHistoryApi
from atriumsports.datacore.openapi.api.person_fixture_statistics_api import PersonFixtureStatisticsApi
from atriumsports.datacore.openapi.api.persons_api import PersonsApi
from atriumsports.datacore.openapi.api.rankings_api import RankingsApi
from atriumsports.datacore.openapi.api.roles_api import RolesApi
from atriumsports.datacore.openapi.api.season_entities_api import SeasonEntitiesApi
from atriumsports.datacore.openapi.api.season_entity_base_statistics_api import SeasonEntityBaseStatisticsApi
from atriumsports.datacore.openapi.api.season_entity_placings_api import SeasonEntityPlacingsApi
from atriumsports.datacore.openapi.api.season_leaders_api import SeasonLeadersApi
from atriumsports.datacore.openapi.api.season_person_base_statistics_api import SeasonPersonBaseStatisticsApi
from atriumsports.datacore.openapi.api.season_person_placings_api import SeasonPersonPlacingsApi
from atriumsports.datacore.openapi.api.season_persons_api import SeasonPersonsApi
from atriumsports.datacore.openapi.api.season_roster_api import SeasonRosterApi
from atriumsports.datacore.openapi.api.season_series_api import SeasonSeriesApi
from atriumsports.datacore.openapi.api.season_statistics_api import SeasonStatisticsApi
from atriumsports.datacore.openapi.api.seasons_api import SeasonsApi
from atriumsports.datacore.openapi.api.sites_api import SitesApi
from atriumsports.datacore.openapi.api.stages_pools_rounds_api import StagesPoolsRoundsApi
from atriumsports.datacore.openapi.api.standing_adjustments_api import StandingAdjustmentsApi
from atriumsports.datacore.openapi.api.standing_configurations_api import StandingConfigurationsApi
from atriumsports.datacore.openapi.api.standings_api import StandingsApi
from atriumsports.datacore.openapi.api.transfers_api import TransfersApi
from atriumsports.datacore.openapi.api.venues_api import VenuesApi
from atriumsports.datacore.openapi.api.video_stream_inputs_api import VideoStreamInputsApi
from atriumsports.datacore.openapi.api.video_stream_subscriptions_api import VideoStreamSubscriptionsApi
from atriumsports.datacore.openapi.api.video_streams_available_api import VideoStreamsAvailableApi

# flake8: noqa

==> atriumsports_sdk-1.9.3.tar.gz: atriumsports_sdk-1.9.3/atriumsports/datacore/openapi/api/__init__.py <==
# flake8: noqa

# import apis into api package
from atriumsports.datacore.openapi.api.awards_api import AwardsApi
from atriumsports.datacore.openapi.api.career_statistics_api import CareerStatisticsApi
from atriumsports.datacore.openapi.api.change_log_api import ChangeLogApi
from atriumsports.datacore.openapi.api.competition_external_ids_api import CompetitionExternalIDsApi
from atriumsports.datacore.openapi.api.competition_statistics_api import CompetitionStatisticsApi
from atriumsports.datacore.openapi.api.competitions_api import CompetitionsApi
from atriumsports.datacore.openapi.api.conduct_api import ConductApi
from atriumsports.datacore.openapi.api.conference_external_ids_api import ConferenceExternalIDsApi
from atriumsports.datacore.openapi.api.conferences_divisions_api import ConferencesDivisionsApi
from atriumsports.datacore.openapi.api.division_external_ids_api import DivisionExternalIDsApi
from atriumsports.datacore.openapi.api.download_video_api import DownloadVideoApi
from atriumsports.datacore.openapi.api.entities_api import EntitiesApi
from atriumsports.datacore.openapi.api.entity_external_ids_api import EntityExternalIDsApi
from atriumsports.datacore.openapi.api.entity_fixture_history_api import EntityFixtureHistoryApi
from atriumsports.datacore.openapi.api.entity_fixture_statistics_api import EntityFixtureStatisticsApi
from atriumsports.datacore.openapi.api.entity_group_external_ids_api import EntityGroupExternalIDsApi
from atriumsports.datacore.openapi.api.entity_groups_api import EntityGroupsApi
from atriumsports.datacore.openapi.api.fixture_entities_api import FixtureEntitiesApi
from atriumsports.datacore.openapi.api.fixture_external_ids_api import FixtureExternalIDsApi
from atriumsports.datacore.openapi.api.fixture_live_summary_api import FixtureLiveSummaryApi
from atriumsports.datacore.openapi.api.fixture_persons_api import FixturePersonsApi
from atriumsports.datacore.openapi.api.fixture_playbyplay_api import FixturePLAYBYPLAYApi
from atriumsports.datacore.openapi.api.fixture_profiles_api import FixtureProfilesApi
from atriumsports.datacore.openapi.api.fixture_progressions_api import FixtureProgressionsApi
from atriumsports.datacore.openapi.api.fixture_roster_api import FixtureRosterApi
from atriumsports.datacore.openapi.api.fixtures_api import FixturesApi
from atriumsports.datacore.openapi.api.images_api import ImagesApi
from atriumsports.datacore.openapi.api.leader_criteria_sets_api import LeaderCriteriaSetsApi
from atriumsports.datacore.openapi.api.leader_qualifiers_api import LeaderQualifiersApi
from atriumsports.datacore.openapi.api.league_external_ids_api import LeagueExternalIDsApi
from atriumsports.datacore.openapi.api.leagues_api import LeaguesApi
from atriumsports.datacore.openapi.api.local_video_endpoints_api import LocalVideoEndpointsApi
from atriumsports.datacore.openapi.api.merge_records_api import MergeRecordsApi
from atriumsports.datacore.openapi.api.organizations_api import OrganizationsApi
from atriumsports.datacore.openapi.api.partner_apis_api import PartnerAPIsApi
from atriumsports.datacore.openapi.api.person_external_ids_api import PersonExternalIDsApi
from atriumsports.datacore.openapi.api.person_fixture_history_api import PersonFixtureHistoryApi
from atriumsports.datacore.openapi.api.person_fixture_statistics_api import PersonFixtureStatisticsApi
from atriumsports.datacore.openapi.api.persons_api import PersonsApi
from atriumsports.datacore.openapi.api.roles_api import RolesApi
from atriumsports.datacore.openapi.api.season_entities_api import SeasonEntitiesApi
from atriumsports.datacore.openapi.api.season_entity_base_statistics_api import SeasonEntityBaseStatisticsApi
from atriumsports.datacore.openapi.api.season_entity_placings_api import SeasonEntityPlacingsApi
from atriumsports.datacore.openapi.api.season_external_ids_api import SeasonExternalIDsApi
from atriumsports.datacore.openapi.api.season_leaders_api import SeasonLeadersApi
from atriumsports.datacore.openapi.api.season_person_base_statistics_api import SeasonPersonBaseStatisticsApi
from atriumsports.datacore.openapi.api.season_person_placings_api import SeasonPersonPlacingsApi
from atriumsports.datacore.openapi.api.season_persons_api import SeasonPersonsApi
from atriumsports.datacore.openapi.api.season_roster_api import SeasonRosterApi
from atriumsports.datacore.openapi.api.season_series_api import SeasonSeriesApi
from atriumsports.datacore.openapi.api.season_statistics_api import SeasonStatisticsApi
from atriumsports.datacore.openapi.api.seasons_api import SeasonsApi
from atriumsports.datacore.openapi.api.site_external_ids_api import SiteExternalIDsApi
from atriumsports.datacore.openapi.api.sites_api import SitesApi
from atriumsports.datacore.openapi.api.stages_pools_rounds_api import StagesPoolsRoundsApi
from atriumsports.datacore.openapi.api.standing_adjustments_api import StandingAdjustmentsApi
from atriumsports.datacore.openapi.api.standing_configurations_api import StandingConfigurationsApi
from atriumsports.datacore.openapi.api.standings_api import StandingsApi
from atriumsports.datacore.openapi.api.transfers_api import TransfersApi
from atriumsports.datacore.openapi.api.venue_external_ids_api import VenueExternalIDsApi
from atriumsports.datacore.openapi.api.venues_api import VenuesApi
from atriumsports.datacore.openapi.api.video_stream_inputs_api import VideoStreamInputsApi
from atriumsports.datacore.openapi.api.video_stream_subscriptions_api import VideoStreamSubscriptionsApi
from atriumsports.datacore.openapi.api.video_streams_available_api import VideoStreamsAvailableApi
